@@ -22,8 +22,14 @@ from streamlink.stream.http import HTTPStream
 log = logging.getLogger(__name__)
 
 
-@pluginmatcher(re.compile(r"https?://(?:www\.)?ok\.ru/"))
-@pluginmatcher(re.compile(r"https?://m(?:obile)?\.ok\.ru/"))
+@pluginmatcher(
+    name="default",
+    pattern=re.compile(r"https?://(?:www\.)?ok\.ru/"),
+)
+@pluginmatcher(
+    name="mobile",
+    pattern=re.compile(r"https?://m(?:obile)?\.ok\.ru/"),
+)
 class OKru(Plugin):
     QUALITY_WEIGHTS = {
         "full": 1080,
@@ -47,21 +53,24 @@ class OKru(Plugin):
         return super().stream_weight(key)
 
     def _get_streams_mobile(self):
-        data = self.session.http.get(self.url, schema=validate.Schema(
-            validate.parse_html(),
-            validate.xml_find(".//a[@data-video]"),
-            validate.get("data-video"),
-            validate.none_or_all(
-                str,
-                validate.parse_json(),
-                {
-                    "videoName": str,
-                    "videoSrc": validate.url(),
-                    "movieId": str,
-                },
-                validate.union_get("movieId", "videoName", "videoSrc"),
+        data = self.session.http.get(
+            self.url,
+            schema=validate.Schema(
+                validate.parse_html(),
+                validate.xml_find(".//a[@data-video]"),
+                validate.get("data-video"),
+                validate.none_or_all(
+                    str,
+                    validate.parse_json(),
+                    {
+                        "videoName": str,
+                        "videoSrc": validate.url(),
+                        "movieId": str,
+                    },
+                    validate.union_get("movieId", "videoName", "videoSrc"),
+                ),
             ),
-        ))
+        )
         if not data:
             return
 
@@ -73,44 +82,57 @@ class OKru(Plugin):
 
         return (
             HLSStream.parse_variant_playlist(self.session, stream_url)
-            if urlparse(stream_url).path.endswith(".m3u8") else
-            {"vod": HTTPStream(self.session, stream_url)}
+            if urlparse(stream_url).path.endswith(".m3u8")
+            else {"vod": HTTPStream(self.session, stream_url)}
         )
 
     def _get_streams_default(self):
         schema_metadata = validate.Schema(
             validate.parse_json(),
             {
-                validate.optional("author"): validate.all({"name": str}, validate.get("name")),
-                validate.optional("movie"): validate.all({"title": str}, validate.get("title")),
+                validate.optional("author"): validate.all({validate.optional("name"): str}, validate.get("name")),
+                validate.optional("movie"): validate.all(
+                    {
+                        validate.optional("id"): str,
+                        validate.optional("title"): str,
+                    },
+                    validate.union_get("id", "title"),
+                ),
                 validate.optional("hlsManifestUrl"): validate.url(),
                 validate.optional("hlsMasterPlaylistUrl"): validate.url(),
                 validate.optional("liveDashManifestUrl"): validate.url(),
-                validate.optional("videos"): [validate.all(
-                    {
-                        "name": str,
-                        "url": validate.url(),
-                    },
-                    validate.union_get("name", "url"),
-                )],
+                validate.optional("videos"): [
+                    validate.all(
+                        {
+                            "name": str,
+                            "url": validate.url(),
+                        },
+                        validate.union_get("name", "url"),
+                    ),
+                ],
             },
         )
 
-        metadata, metadata_url = self.session.http.get(self.url, schema=validate.Schema(
-            validate.parse_html(),
-            validate.xml_find(".//*[@data-options]"),
-            validate.get("data-options"),
-            validate.parse_json(),
-            {"flashvars": {
-                validate.optional("metadata"): str,
-                validate.optional("metadataUrl"): validate.all(
-                    validate.transform(unquote),
-                    validate.url(),
-                ),
-            }},
-            validate.get("flashvars"),
-            validate.union_get("metadata", "metadataUrl"),
-        ))
+        metadata, metadata_url = self.session.http.get(
+            self.url,
+            schema=validate.Schema(
+                validate.parse_html(),
+                validate.xml_find(".//*[@data-options]"),
+                validate.get("data-options"),
+                validate.parse_json(),
+                {
+                    "flashvars": {
+                        validate.optional("metadata"): str,
+                        validate.optional("metadataUrl"): validate.all(
+                            validate.transform(unquote),
+                            validate.url(),
+                        ),
+                    },
+                },
+                validate.get("flashvars"),
+                validate.union_get("metadata", "metadataUrl"),
+            ),
+        )
 
         self.session.http.headers.update({"Referer": self.url})
 
@@ -122,7 +144,7 @@ class OKru(Plugin):
         data = schema_metadata.validate(metadata)
 
         self.author = data.get("author")
-        self.title = data.get("movie")
+        self.id, self.title = data.get("movie", (None, None))
 
         for hls_url in data.get("hlsManifestUrl"), data.get("hlsMasterPlaylistUrl"):
             if hls_url is not None:
@@ -137,7 +159,7 @@ class OKru(Plugin):
         }
 
     def _get_streams(self):
-        return self._get_streams_default() if self.matches[0] else self._get_streams_mobile()
+        return self._get_streams_default() if self.matches["default"] else self._get_streams_mobile()
 
 
 __plugin__ = OKru
