@@ -1,10 +1,10 @@
+from __future__ import annotations
+
 import os
 import tempfile
 from pathlib import Path
-from typing import List
 
 from streamlink.compat import is_darwin, is_win32
-from streamlink_cli.compat import DeprecatedPath
 
 
 DEFAULT_STREAM_METADATA = {
@@ -15,15 +15,14 @@ DEFAULT_STREAM_METADATA = {
     "game": "No Game/Category",
 }
 
-CONFIG_FILES: List[Path]
-PLUGIN_DIRS: List[Path]
+CONFIG_FILES: list[Path]
+PLUGIN_DIRS: list[Path]
 LOG_DIR: Path
 
 if is_win32:
     APPDATA = Path(os.environ.get("APPDATA") or Path.home() / "AppData")
     CONFIG_FILES = [
         APPDATA / "streamlink" / "config",
-        DeprecatedPath(APPDATA / "streamlink" / "streamlinkrc"),
     ]
     PLUGIN_DIRS = [
         APPDATA / "streamlink" / "plugins",
@@ -33,25 +32,20 @@ elif is_darwin:
     XDG_CONFIG_HOME = Path(os.environ.get("XDG_CONFIG_HOME", "~/.config")).expanduser()
     CONFIG_FILES = [
         Path.home() / "Library" / "Application Support" / "streamlink" / "config",
-        DeprecatedPath(XDG_CONFIG_HOME / "streamlink" / "config"),
-        DeprecatedPath(Path.home() / ".streamlinkrc"),
     ]
     PLUGIN_DIRS = [
         Path.home() / "Library" / "Application Support" / "streamlink" / "plugins",
-        DeprecatedPath(XDG_CONFIG_HOME / "streamlink" / "plugins"),
     ]
-    LOG_DIR = DeprecatedPath(Path.home() / "Library" / "Logs" / "streamlink")
+    LOG_DIR = Path.home() / "Library" / "Logs" / "streamlink"
 else:
     XDG_CONFIG_HOME = Path(os.environ.get("XDG_CONFIG_HOME", "~/.config")).expanduser()
     XDG_DATA_HOME = Path(os.environ.get("XDG_DATA_HOME", "~/.local/share")).expanduser()
     XDG_STATE_HOME = Path(os.environ.get("XDG_STATE_HOME", "~/.local/state")).expanduser()
     CONFIG_FILES = [
         XDG_CONFIG_HOME / "streamlink" / "config",
-        DeprecatedPath(Path.home() / ".streamlinkrc"),
     ]
     PLUGIN_DIRS = [
         XDG_DATA_HOME / "streamlink" / "plugins",
-        DeprecatedPath(XDG_CONFIG_HOME / "streamlink" / "plugins"),
     ]
     LOG_DIR = XDG_STATE_HOME / "streamlink" / "logs"
 
