@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import argparse
 import importlib.metadata
 import logging
@@ -8,25 +10,33 @@ import signal
 import ssl
 import sys
 import warnings
+from collections.abc import Mapping
 from contextlib import closing, suppress
 from gettext import gettext
 from pathlib import Path
 from time import sleep
-from typing import Any, Dict, List, Optional, Type, Union
+from typing import Any
 
 import streamlink.logger as logger
 from streamlink import NoPluginError, PluginError, StreamError, Streamlink, __version__ as streamlink_version
 from streamlink.exceptions import FatalPluginError, StreamlinkDeprecationWarning
-from streamlink.options import Options
 from streamlink.plugin import Plugin
 from streamlink.stream.stream import Stream, StreamIO
 from streamlink.utils.named_pipe import NamedPipe
 from streamlink.utils.times import LOCAL as LOCALTIMEZONE
-from streamlink_cli.argparser import ArgumentParser, build_parser, setup_session_options
-from streamlink_cli.compat import DeprecatedPath, stdout
+from streamlink_cli.argparser import (
+    ArgumentParser,
+    build_parser,
+    setup_plugin_args,
+    setup_plugin_options,
+    setup_session_options,
+)
+from streamlink_cli.compat import stdout
 from streamlink_cli.console import ConsoleOutput, ConsoleUserInputRequester
 from streamlink_cli.constants import CONFIG_FILES, DEFAULT_STREAM_METADATA, LOG_DIR, PLUGIN_DIRS, STREAM_SYNONYMS
+from streamlink_cli.exceptions import StreamlinkCLIError
 from streamlink_cli.output import FileOutput, HTTPOutput, PlayerOutput
+from streamlink_cli.show_matchers import show_matchers
 from streamlink_cli.streamrunner import StreamRunner
 from streamlink_cli.utils import Formatter, datetime
 from streamlink_cli.utils.versioncheck import check_version
@@ -37,7 +47,7 @@ QUIET_OPTIONS = ("json", "stream_url", "quiet")
 
 args: Any = None  # type: ignore[assignment]
 console: ConsoleOutput = None  # type: ignore[assignment]
-output: Union[FileOutput, PlayerOutput] = None  # type: ignore[assignment]
+output: FileOutput | PlayerOutput = None  # type: ignore[assignment]
 stream_fd: StreamIO = None  # type: ignore[assignment]
 streamlink: Streamlink = None  # type: ignore[assignment]
 
@@ -63,26 +73,31 @@ def get_formatter(plugin: Plugin):
     )
 
 
-def check_file_output(path: Path, force):
-    """Checks if file already exists and ask the user if it should
-    be overwritten if it does."""
+def check_file_output(path: Path, force: bool) -> Path:
+    """
+    Checks if path already exists and asks the user if it should be overwritten if it does.
+    """
 
-    log.info(f"Writing output to\n{path.resolve()}")
+    # rewrap path and resolve using `os.path.realpath` instead of `path.resolve()`
+    # to avoid a pathlib issues on py39 and below
+    realpath = Path(os.path.realpath(path))
+
+    log.info(f"Writing output to\n{realpath}")
     log.debug("Checking file output")
 
-    if path.is_file() and not force:
-        if sys.stdin.isatty():
+    if realpath.is_file() and not force:
+        if sys.stdin and sys.stdin.isatty():
             answer = console.ask(f"File {path} already exists! Overwrite it? [y/N] ")
             if not answer or answer.lower() != "y":
-                sys.exit()
+                raise StreamlinkCLIError()
         else:
             log.error(f"File {path} already exists, use --force to overwrite it.")
-            sys.exit()
+            raise StreamlinkCLIError()
 
-    return FileOutput(path)
+    return realpath
 
 
-def create_output(formatter: Formatter) -> Union[FileOutput, PlayerOutput]:
+def create_output(formatter: Formatter) -> FileOutput | PlayerOutput:
     """Decides where to write the stream.
 
     Depending on arguments it can be one of these:
@@ -93,41 +108,45 @@ def create_output(formatter: Formatter) -> Union[FileOutput, PlayerOutput]:
 
     """
 
-    if (args.output or args.stdout) and (args.record or args.record_and_pipe):
-        console.exit("Cannot use record options with other file output options.")
-        return  # type: ignore
-
     if args.output:
+        if args.stdout:
+            raise StreamlinkCLIError("The -o/--output argument is incompatible with -O/--stdout")
+        if args.record or args.record_and_pipe:
+            raise StreamlinkCLIError("The -o/--output argument is incompatible with -r/--record and -R/--record-and-pipe")
+
         if args.output == "-":
             return FileOutput(fd=stdout)
         else:
-            return check_file_output(formatter.path(args.output, args.fs_safe_rules), args.force)
+            filename = check_file_output(formatter.path(args.output, args.fs_safe_rules), args.force)
+            return FileOutput(filename=filename)
 
     elif args.stdout:
-        return FileOutput(fd=stdout)
+        if args.record_and_pipe:
+            raise StreamlinkCLIError("The -O/--stdout argument is incompatible with -R/--record-and-pipe")
+
+        if not args.record or args.record == "-":
+            return FileOutput(fd=stdout)
+        else:
+            filename = check_file_output(formatter.path(args.record, args.fs_safe_rules), args.force)
+            return FileOutput(fd=stdout, record=FileOutput(filename=filename))
 
     elif args.record_and_pipe:
-        record = check_file_output(formatter.path(args.record_and_pipe, args.fs_safe_rules), args.force)
-        return FileOutput(fd=stdout, record=record)
-
-    elif not args.player:
-        console.exit(
-            "The default player (VLC) does not seem to be installed."
-            + " You must specify the path to a player executable with --player,"
-            + " a file path to save the stream with --output,"
-            + " or pipe the stream to another program with --stdout.",
+        warnings.warn(
+            "-R/--record-and-pipe=... has been deprecated in favor of --stdout --record=...",
+            StreamlinkDeprecationWarning,
+            stacklevel=1,
         )
-        return  # type: ignore
+        filename = check_file_output(formatter.path(args.record_and_pipe, args.fs_safe_rules), args.force)
+        return FileOutput(fd=stdout, record=FileOutput(filename=filename))
 
-    else:
+    elif args.player:
         http = namedpipe = record = None
 
         if args.player_fifo:
             try:
                 namedpipe = NamedPipe()  # type: ignore[abstract]  # ???
             except OSError as err:
-                console.exit(f"Failed to create pipe: {err}")
-                return  # type: ignore
+                raise StreamlinkCLIError(f"Failed to create pipe: {err}") from err
         elif args.player_http:
             http = create_http_server()
 
@@ -135,7 +154,8 @@ def create_output(formatter: Formatter) -> Union[FileOutput, PlayerOutput]:
             if args.record == "-":
                 record = FileOutput(fd=stdout)
             else:
-                record = check_file_output(formatter.path(args.record, args.fs_safe_rules), args.force)
+                filename = check_file_output(formatter.path(args.record, args.fs_safe_rules), args.force)
+                record = FileOutput(filename=filename)
 
         log.info(f"Starting player: {args.player}")
 
@@ -143,7 +163,7 @@ def create_output(formatter: Formatter) -> Union[FileOutput, PlayerOutput]:
             path=args.player,
             args=args.player_args,
             env=args.player_env,
-            quiet=not args.verbose_player,
+            quiet=not args.player_verbose,
             kill=not args.player_no_close,
             namedpipe=namedpipe,
             http=http,
@@ -151,8 +171,15 @@ def create_output(formatter: Formatter) -> Union[FileOutput, PlayerOutput]:
             title=formatter.title(args.title, defaults=DEFAULT_STREAM_METADATA) if args.title else args.url,
         )
 
+    raise StreamlinkCLIError(
+        "The default player (VLC) does not seem to be installed."
+        + " You must specify the path to a player executable with --player,"
+        + " a file path to save the stream with --output,"
+        + " or pipe the stream to another program with --stdout.",
+    )
 
-def create_http_server(host: Optional[str] = None, port: int = 0) -> HTTPOutput:
+
+def create_http_server(host: str | None = None, port: int = 0) -> HTTPOutput:
     """
     Create an HTTP server listening on a given host and port.
     If host is None, listen on all available interfaces.
@@ -164,13 +191,12 @@ def create_http_server(host: Optional[str] = None, port: int = 0) -> HTTPOutput:
         httpoutput.start_server()
         return httpoutput
     except OSError as err:
-        console.exit(f"Failed to create HTTP server: {err}")
-        raise
+        raise StreamlinkCLIError(f"Failed to create HTTP server: {err}") from err
 
 
 def output_stream_http(
     plugin: Plugin,
-    initial_streams: Dict[str, Stream],
+    initial_streams: Mapping[str, Stream],
     formatter: Formatter,
     external: bool = False,
     continuous: bool = True,
@@ -181,7 +207,7 @@ def output_stream_http(
 
     if not external:
         if not args.player:
-            console.exit(
+            raise StreamlinkCLIError(
                 "The default player (VLC) does not seem to be installed."
                 + " You must specify the path to a player executable with --player.",
             )
@@ -191,7 +217,7 @@ def output_stream_http(
             path=args.player,
             args=args.player_args,
             env=args.player_env,
-            quiet=not args.verbose_player,
+            quiet=not args.player_verbose,
             filename=server.url,
             title=formatter.title(args.title, defaults=DEFAULT_STREAM_METADATA) if args.title else args.url,
         )
@@ -201,7 +227,7 @@ def output_stream_http(
             if player:
                 player.open()
         except OSError as err:
-            console.exit(f"Failed to start player: {args.player} ({err})")
+            raise StreamlinkCLIError(f"Failed to start player: {args.player} ({err})") from err
     else:
         server = create_http_server(args.player_external_http_interface, port)
         player = None
@@ -254,8 +280,7 @@ def output_stream_http(
             try:
                 stream_runner.run(prebuffer)
             except OSError as err:
-                # TODO: refactor all console.exit() calls
-                console.exit(str(err))
+                raise StreamlinkCLIError() from err
 
         if not continuous:
             break
@@ -274,14 +299,19 @@ def output_stream_passthrough(stream, formatter: Formatter):
     try:
         url = stream.to_url()
     except TypeError:
-        console.exit("The stream specified cannot be translated to a URL")
-        return False
+        raise StreamlinkCLIError("The stream specified cannot be translated to a URL") from None
+
+    if not args.player:
+        raise StreamlinkCLIError(
+            "The default player (VLC) does not seem to be installed."
+            + " You must specify the path to a player executable with --player.",
+        )
 
     output = PlayerOutput(
         path=args.player,
         args=args.player_args,
         env=args.player_env,
-        quiet=not args.verbose_player,
+        quiet=not args.player_verbose,
         call=True,
         filename=url,
         title=formatter.title(args.title, defaults=DEFAULT_STREAM_METADATA) if args.title else args.url,
@@ -291,8 +321,7 @@ def output_stream_passthrough(stream, formatter: Formatter):
         log.info(f"Starting player: {args.player}")
         output.open()
     except OSError as err:
-        console.exit(f"Failed to start player: {args.player} ({err})")
-        return False
+        raise StreamlinkCLIError(f"Failed to start player: {args.player} ({err})") from err
 
     return True
 
@@ -345,43 +374,37 @@ def output_stream(stream, formatter: Formatter):
             log.error(f"Try {i + 1}/{args.retry_open}: Could not open stream {stream} ({err})")
 
     if not success_open:
-        return console.exit(f"Could not open stream {stream}, tried {args.retry_open} times, exiting")
+        raise StreamlinkCLIError(f"Could not open stream {stream}, tried {args.retry_open} times, exiting")
 
     try:
         output.open()
     except OSError as err:
         if isinstance(output, PlayerOutput):
-            console.exit(f"Failed to start player: {args.player} ({err})")
+            raise StreamlinkCLIError(f"Failed to start player: {args.player} ({err})") from err
         elif output.filename:
-            console.exit(f"Failed to open output: {output.filename} ({err})")
+            raise StreamlinkCLIError(f"Failed to open output: {output.filename} ({err})") from err
         else:
-            console.exit(f"Failed to open output ({err}")
-        return
+            raise StreamlinkCLIError(f"Failed to open output ({err})") from err
 
     try:
         with closing(output):
             log.debug("Writing stream to output")
-            show_progress = args.progress == "force" or args.progress == "yes" and sys.stderr.isatty()
-            if args.force_progress:
-                show_progress = True
-                warnings.warn(
-                    "The --force-progress option has been deprecated in favor of --progress=force",
-                    StreamlinkDeprecationWarning,
-                    stacklevel=1,
-                )
+            show_progress = (
+                args.progress == "force"
+                or args.progress == "yes" and (sys.stderr.isatty() if sys.stderr else False)
+            )  # fmt: skip
             # TODO: finally clean up the global variable mess and refactor the streamlink_cli package
             # noinspection PyUnboundLocalVariable
             stream_runner = StreamRunner(stream_fd, output, show_progress=show_progress)
             # noinspection PyUnboundLocalVariable
             stream_runner.run(prebuffer)
     except OSError as err:
-        # TODO: refactor all console.exit() calls
-        console.exit(str(err))
+        raise StreamlinkCLIError() from err
 
     return True
 
 
-def handle_stream(plugin: Plugin, streams: Dict[str, Stream], stream_name: str) -> None:
+def handle_stream(plugin: Plugin, streams: Mapping[str, Stream], stream_name: str) -> None:
     """Decides what to do with the selected stream.
 
     Depending on arguments it can be one of these:
@@ -406,7 +429,7 @@ def handle_stream(plugin: Plugin, streams: Dict[str, Stream], stream_name: str)
         try:
             console.msg(stream.to_url())
         except TypeError:
-            console.exit("The stream specified cannot be translated to a URL")
+            raise StreamlinkCLIError("The stream specified cannot be translated to a URL") from None
 
     else:
         # Find any streams with a '_alt' suffix and attempt
@@ -443,16 +466,17 @@ def handle_stream(plugin: Plugin, streams: Dict[str, Stream], stream_name: str)
                 break
 
 
-def fetch_streams(plugin: Plugin) -> Dict[str, Stream]:
+def fetch_streams(plugin: Plugin) -> Mapping[str, Stream]:
     """Fetches streams using correct parameters."""
 
-    return plugin.streams(stream_types=args.stream_types,
-                          sorting_excludes=args.stream_sorting_excludes)
+    return plugin.streams(
+        stream_types=args.stream_types,
+        sorting_excludes=args.stream_sorting_excludes,
+    )
 
 
-def fetch_streams_with_retry(plugin: Plugin, interval: float, count: int) -> Optional[Dict[str, Stream]]:
-    """Attempts to fetch streams repeatedly
-       until some are returned or limit hit."""
+def fetch_streams_with_retry(plugin: Plugin, interval: float, count: int) -> Mapping[str, Stream] | None:
+    """Attempts to fetch streams repeatedly until some are returned or limit hit."""
 
     try:
         streams = fetch_streams(plugin)
@@ -482,7 +506,7 @@ def fetch_streams_with_retry(plugin: Plugin, interval: float, count: int) -> Opt
     return streams
 
 
-def resolve_stream_name(streams: Dict[str, Stream], stream_name: str) -> str:
+def resolve_stream_name(streams: Mapping[str, Stream], stream_name: str) -> str:
     """Returns the real stream name of a synonym."""
 
     if stream_name in STREAM_SYNONYMS and stream_name in streams:
@@ -493,7 +517,7 @@ def resolve_stream_name(streams: Dict[str, Stream], stream_name: str) -> str:
     return stream_name
 
 
-def format_valid_streams(plugin: Plugin, streams: Dict[str, Stream]) -> str:
+def format_valid_streams(plugin: Plugin, streams: Mapping[str, Stream]) -> str:
     """Formats a dict of streams.
 
     Filters out synonyms and displays them next to
@@ -522,6 +546,30 @@ def format_valid_streams(plugin: Plugin, streams: Dict[str, Stream]) -> str:
     return delimiter.join(validstreams)
 
 
+def handle_url_wrapper() -> int:
+    exit_code = 0
+    try:
+        handle_url()
+    except KeyboardInterrupt:
+        # Close output
+        if output:
+            try:
+                output.close()
+            except KeyboardInterrupt:
+                pass
+        console.msg("Interrupted! Exiting...")
+        exit_code = 128 + signal.SIGINT
+    finally:
+        if stream_fd:
+            try:
+                log.info("Closing currently open stream...")
+                stream_fd.close()
+            except KeyboardInterrupt:
+                exit_code = 128 + signal.SIGINT
+
+    return exit_code
+
+
 def handle_url():
     """The URL handler.
 
@@ -535,7 +583,7 @@ def handle_url():
 
     try:
         pluginname, pluginclass, resolved_url = streamlink.resolve_url(args.url)
-        options = setup_plugin_options(pluginname, pluginclass)
+        options = setup_plugin_options(streamlink, args, pluginname, pluginclass)
         plugin = pluginclass(streamlink, resolved_url, options)
         log.info(f"Found matching plugin {pluginname} for URL {args.url}")
 
@@ -550,12 +598,12 @@ def handle_url():
         else:
             streams = fetch_streams(plugin)
     except NoPluginError:
-        console.exit(f"No plugin can handle URL: {args.url}")
+        raise StreamlinkCLIError(f"No plugin can handle URL: {args.url}") from None
     except PluginError as err:
-        console.exit(str(err))
+        raise StreamlinkCLIError() from err
 
     if not streams:
-        console.exit(f"No playable streams found on this URL: {args.url}")
+        raise StreamlinkCLIError(f"No playable streams found on this URL: {args.url}")
 
     if args.default_stream and not args.stream and not args.json:
         args.stream = args.default_stream
@@ -569,15 +617,15 @@ def handle_url():
                 return
 
         errmsg = f"The specified stream(s) '{', '.join(args.stream)}' could not be found"
-        if args.json:
-            console.msg_json(
-                plugin=plugin.module,
-                metadata=plugin.get_metadata(),
-                streams=streams,
-                error=errmsg,
-            )
-        else:
-            console.exit(f"{errmsg}.\n       Available streams: {validstreams}")
+        if not args.json:
+            raise StreamlinkCLIError(f"{errmsg}.\n       Available streams: {validstreams}")
+        console.msg_json(
+            plugin=plugin.module,
+            metadata=plugin.get_metadata(),
+            streams=streams,
+            error=errmsg,
+        )
+        raise StreamlinkCLIError()
     elif args.json:
         console.msg_json(
             plugin=plugin.module,
@@ -588,42 +636,62 @@ def handle_url():
         try:
             console.msg(streams[list(streams)[-1]].to_manifest_url())
         except TypeError:
-            console.exit("The stream specified cannot be translated to a URL")
+            raise StreamlinkCLIError("The stream specified cannot be translated to a URL") from None
     else:
         validstreams = format_valid_streams(plugin, streams)
         console.msg(f"Available streams: {validstreams}")
 
 
+def check_version_wrapper() -> int:
+    force = args.version_check
+
+    try:
+        latest = check_version(force=force)
+        if not force:
+            return 0
+        if latest:
+            return 0
+        return 1
+    except KeyboardInterrupt:
+        return 128 + signal.SIGINT
+
+
 def print_plugins():
     """Outputs a list of all plugins Streamlink has loaded."""
 
-    pluginlist = list(streamlink.get_plugins().keys())
-    pluginlist_formatted = ", ".join(sorted(pluginlist))
+    pluginlist = streamlink.plugins.get_names()
 
     if args.json:
         console.msg_json(pluginlist)
     else:
-        console.msg(f"Loaded plugins: {pluginlist_formatted}")
+        console.msg(f"Available plugins: {', '.join(pluginlist)}")
 
 
-def load_plugins(dirs: List[Path], showwarning: bool = True):
+def can_handle_url() -> int:
+    url = args.can_handle_url or args.can_handle_url_no_redirect or ""
+    follow_redirect = bool(args.can_handle_url)
+
+    try:
+        streamlink.resolve_url(url, follow_redirect=follow_redirect)
+        return 0
+    except NoPluginError:
+        return 1
+    except KeyboardInterrupt:
+        return 128 + signal.SIGINT
+
+
+def load_plugins(dirs: list[Path], showwarning: bool = True):
     """Attempts to load plugins from a list of directories."""
     for directory in dirs:
         if directory.is_dir():
-            success = streamlink.load_plugins(str(directory))
-            if success and type(directory) is DeprecatedPath:
-                warnings.warn(
-                    f"Loaded plugins from deprecated path, see CLI docs for how to migrate: {directory}",
-                    StreamlinkDeprecationWarning,
-                    stacklevel=1,
-                )
+            streamlink.plugins.load_path(directory)
         elif showwarning:
             log.warning(f"Plugin path {directory} does not exist or is not a directory!")
 
 
 def setup_args(
     parser: argparse.ArgumentParser,
-    config_files: Optional[List[Path]] = None,
+    config_files: list[Path] | None = None,
     ignore_unknown: bool = False,
 ):
     """Parses arguments."""
@@ -631,7 +699,8 @@ def setup_args(
     arglist = sys.argv[1:]
 
     # Load arguments from config files
-    configs = [f"@{config_file}" for config_file in config_files or []]
+    prefix = parser.fromfile_prefix_chars or "@"
+    configs = [f"{prefix}{config_file}" for config_file in config_files or []]
 
     args, unknown = parser.parse_known_args(configs + arglist)
     if unknown and not ignore_unknown:
@@ -658,17 +727,11 @@ def setup_config_args(parser, ignore_unknown=False):
             config_file
             for config_file in [Path(path).expanduser() for path in reversed(args.config)]
             if config_file.is_file()
-        )
+        )  # fmt: skip
 
     else:
         # Only load first available default config
         for config_file in filter(lambda path: path.is_file(), CONFIG_FILES):  # pragma: no branch
-            if type(config_file) is DeprecatedPath:
-                warnings.warn(
-                    f"Loaded config from deprecated path, see CLI docs for how to migrate: {config_file}",
-                    StreamlinkDeprecationWarning,
-                    stacklevel=1,
-                )
             config_files.append(config_file)
             break
 
@@ -680,12 +743,6 @@ def setup_config_args(parser, ignore_unknown=False):
                 config_file = config_file.with_name(f"{config_file.name}.{pluginname}")
                 if not config_file.is_file():
                     continue
-                if type(config_file) is DeprecatedPath:
-                    warnings.warn(
-                        f"Loaded plugin config from deprecated path, see CLI docs for how to migrate: {config_file}",
-                        StreamlinkDeprecationWarning,
-                        stacklevel=1,
-                    )
                 config_files.append(config_file)
                 break
 
@@ -715,67 +772,13 @@ def setup_streamlink():
     streamlink = Streamlink({"user-input-requester": ConsoleUserInputRequester(console)})
 
 
-def setup_plugin_args(session: Streamlink, parser: ArgumentParser):
-    """Adds plugin argument data to the argument parser."""
-
-    plugin_args = parser.add_argument_group("Plugin options")
-    for pname, plugin in session.plugins.items():
-        group = parser.add_argument_group(pname.capitalize(), parent=plugin_args)
-
-        for parg in plugin.arguments or []:
-            group.add_argument(parg.argument_name(pname), **parg.options)
-
-
-def setup_plugin_options(pluginname: str, pluginclass: Type[Plugin]) -> Options:
-    """Initializes plugin options from argument values."""
-
-    if not pluginclass.arguments:
-        return Options()
-
-    defaults = {}
-    values = {}
-    required = {}
-
-    for parg in pluginclass.arguments:
-        defaults[parg.dest] = parg.default
-
-        if parg.options.get("help") == argparse.SUPPRESS:
-            continue
-
-        value = getattr(args, parg.namespace_dest(pluginname))
-        values[parg.dest] = value
-
-        if parg.required:
-            required[parg.name] = parg
-        # if the value is set, check to see if any of the required arguments are not set
-        if parg.required or value:
-            try:
-                for rparg in pluginclass.arguments.requires(parg.name):
-                    required[rparg.name] = rparg
-            except RuntimeError:  # pragma: no cover
-                log.error(f"{pluginname} plugin has a configuration error and the arguments cannot be parsed")
-                break
-
-    for req in required.values():
-        if not values.get(req.dest):
-            prompt = f"{req.prompt or f'Enter {pluginname} {req.name}'}: "
-            value = console.askpass(prompt) if req.sensitive else console.ask(prompt)
-            values[req.dest] = value
-
-    options = Options(defaults)
-    options.update(values)
-
-    return options
-
-
 def log_root_warning():
     if hasattr(os, "geteuid"):  # pragma: no branch
         if os.geteuid() == 0:
             log.info("streamlink is running as root! Be careful!")
 
 
-def log_current_versions():
-    """Show current installed versions"""
+def log_current_versions() -> None:
     if not logger.root.isEnabledFor(logging.DEBUG):
         return
 
@@ -794,14 +797,17 @@ def log_current_versions():
     log.debug(f"OpenSSL:    {ssl.OPENSSL_VERSION}")
     log.debug(f"Streamlink: {streamlink_version}")
 
+    log.debug("Dependencies:")
     # https://peps.python.org/pep-0508/#names
     re_name = re.compile(r"[A-Z\d](?:[A-Z\d._-]*[A-Z\d])?", re.IGNORECASE)
-    log.debug("Dependencies:")
-    for name in [
-        match.group(0)
-        for match in map(re_name.match, importlib.metadata.requires("streamlink"))
+    dependencies: list[str] = importlib.metadata.requires("streamlink") or []
+    dependency_names: set[str] = {
+        match[0]
+        for match in [re_name.match(item) for item in dependencies]
         if match is not None
-    ]:
+    }  # fmt: skip
+    # noinspection PyTypeChecker
+    for name in sorted(dependency_names, key=str.lower):
         try:
             version = importlib.metadata.version(name)
         except importlib.metadata.PackageNotFoundError:
@@ -814,53 +820,79 @@ def log_current_arguments(session: Streamlink, parser: argparse.ArgumentParser):
         return
 
     sensitive = set()
-    for pname, plugin in session.plugins.items():
-        for parg in plugin.arguments or []:
+    for pname, arguments in session.plugins.iter_arguments():
+        for parg in arguments:
             if parg.sensitive:
                 sensitive.add(parg.argument_name(pname))
 
     log.debug("Arguments:")
+    seen = set()
     for action in parser._actions:
-        if not hasattr(args, action.dest):
+        if not hasattr(args, action.dest) or action.dest in seen:
             continue
+        seen.add(action.dest)
         value = getattr(args, action.dest)
         if action.default != value:
-            name = next(  # pragma: no branch
-                (option for option in action.option_strings if option.startswith("--")),
-                action.option_strings[0],
-            ) if action.option_strings else action.dest
+            name = (
+                next(  # pragma: no branch
+                    (option for option in action.option_strings if option.startswith("--")),
+                    action.option_strings[0],
+                )
+                if action.option_strings
+                else action.dest
+            )  # fmt: skip
             log.debug(f" {name}={value if name not in sensitive else '*' * 8}")
 
 
-def setup_logger_and_console(stream=sys.stdout, filename=None, level="info", json=False):
+def setup_logger_and_console(
+    stream=sys.stdout,
+    level: str = "info",
+    fmt: str | None = None,
+    datefmt: str | None = None,
+    file: str | None = None,
+    json=False,
+):
     global console
 
-    if filename == "-":
+    verbose = level in ("trace", "all")
+    if not fmt:
+        if verbose:
+            fmt = "[{asctime}][{name}][{levelname}] {message}"
+        else:
+            fmt = "[{name}][{levelname}] {message}"
+    if not datefmt:
+        if verbose:
+            datefmt = "%H:%M:%S.%f"
+        else:
+            datefmt = "%H:%M:%S"
+
+    if file == "-":
         filename = LOG_DIR / f"{datetime.now(tz=LOCALTIMEZONE)}.log"
-    elif filename:
-        filename = Path(filename).expanduser().resolve()
+    elif file:
+        filename = Path(file).expanduser().resolve()
+    else:
+        filename = None
 
     if filename:
         filename.parent.mkdir(parents=True, exist_ok=True)
 
-    verbose = level in ("trace", "all")
-    streamhandler = logger.basicConfig(
-        stream=stream,
-        filename=filename,
-        level=level,
-        style="{",
-        format=f"{'[{asctime}]' if verbose else ''}[{{name}}][{{levelname}}] {{message}}",
-        datefmt=f"%H:%M:%S{'.%f' if verbose else ''}",
-        capture_warnings=True,
-    )
+    try:
+        streamhandler = logger.basicConfig(
+            filename=filename,
+            format=fmt,
+            datefmt=datefmt,
+            style="{",
+            level=level,
+            stream=stream,
+            capture_warnings=True,
+        )
+    except Exception as err:
+        raise StreamlinkCLIError(f"Logging setup error: {err}") from err
 
     console = ConsoleOutput(streamhandler.stream, json)
 
 
-def main():
-    error_code = 0
-    parser = build_parser()
-
+def setup(parser: ArgumentParser) -> None:
     setup_args(parser, ignore_unknown=True)
     # call argument set up as early as possible to load args from config files
     setup_config_args(parser, ignore_unknown=True)
@@ -876,7 +908,14 @@ def main():
     silent_log = any(getattr(args, attr) for attr in QUIET_OPTIONS)
     log_level = args.loglevel if not silent_log else "none"
     log_file = args.logfile if log_level != "none" else None
-    setup_logger_and_console(console_out, log_file, log_level, args.json)
+    setup_logger_and_console(
+        stream=console_out,
+        level=log_level,
+        fmt=args.logformat,
+        datefmt=args.logdateformat,
+        file=log_file,
+        json=args.json,
+    )
 
     setup_streamlink()
     # load additional plugins
@@ -898,60 +937,55 @@ def main():
 
     setup_signals()
 
+
+def run(parser: ArgumentParser) -> int:
+    exit_code = 0
+
     if args.version_check or args.auto_version_check:
-        try:
-            check_version(force=args.version_check)
-        except KeyboardInterrupt:
-            error_code = 130
+        exit_code = check_version_wrapper()
 
     if args.version_check:
         pass
     elif args.help:
-        parser.print_help()
+        helptext = parser.format_help()
+        console.msg(helptext)
     elif args.plugins:
         print_plugins()
-    elif args.can_handle_url:
-        try:
-            streamlink.resolve_url(args.can_handle_url)
-        except NoPluginError:
-            error_code = 1
-        except KeyboardInterrupt:
-            error_code = 130
-    elif args.can_handle_url_no_redirect:
-        try:
-            streamlink.resolve_url_no_redirect(args.can_handle_url_no_redirect)
-        except NoPluginError:
-            error_code = 1
-        except KeyboardInterrupt:
-            error_code = 130
+    elif args.show_matchers:
+        show_matchers(streamlink, console, args.show_matchers)
+    elif args.can_handle_url or args.can_handle_url_no_redirect:
+        exit_code = can_handle_url()
     elif args.url:
-        try:
-            handle_url()
-        except KeyboardInterrupt:
-            # Close output
-            if output:
-                output.close()
-            console.msg("Interrupted! Exiting...")
-            error_code = 130
-        finally:
-            if stream_fd:
-                try:
-                    log.info("Closing currently open stream...")
-                    stream_fd.close()
-                except KeyboardInterrupt:
-                    error_code = 130
+        exit_code = handle_url_wrapper()
     else:
         usage = parser.format_usage()
-        console.msg(
-            f"{usage}\n"
-            + "Use -h/--help to see the available options or read the manual at https://streamlink.github.io",
-        )
+        console.msg(f"{usage}\nUse -h/--help to see the available options or read the manual at https://streamlink.github.io/")
 
-    sys.exit(error_code)
+    return exit_code
 
 
-def parser_helper():
-    session = Streamlink()
-    parser = build_parser()
-    setup_plugin_args(session, parser)
-    return parser
+def main():
+    try:
+        parser = build_parser()
+        setup(parser)
+    except StreamlinkCLIError as err:
+        sys.stderr.write(f"{err}\n")
+        sys.exit(1)
+
+    try:
+        exit_code = run(parser)
+    except StreamlinkCLIError as err:
+        exit_code = err.code
+        if msg := str(err):  # pragma: no branch
+            if console.json:
+                console.msg_json({"error": msg})
+            else:
+                console.msg(f"error: {msg}")
+
+    # https://docs.python.org/3/library/signal.html#note-on-sigpipe
+    try:
+        sys.stdout.flush()
+    except (AttributeError, OSError):
+        del sys.stdout
+
+    sys.exit(exit_code)
