@@ -22,35 +22,43 @@ class TestProgressFormatter:
         )
 
     @pytest.fixture(autouse=True)
-    def term_width(self, request: pytest.FixtureRequest, monkeypatch: pytest.MonkeyPatch):  # noqa: PT004
+    def term_width(self, request: pytest.FixtureRequest, monkeypatch: pytest.MonkeyPatch):
         width = getattr(request, "param", 99)
         monkeypatch.setattr("streamlink_cli.utils.progress.ProgressFormatter.term_width", lambda: width)
 
-    @pytest.mark.parametrize(("term_width", "expected"), [
-        (99, "[download] Written WRITTEN to PATH (ELAPSED @ SPEED)"),
-        (63, "[download] Written WRITTEN to PATH (ELAPSED @ SPEED)"),
-        (62, "[download] Written WRITTEN (ELAPSED @ SPEED)"),
-        (44, "[download] Written WRITTEN (ELAPSED @ SPEED)"),
-        (43, "[download] WRITTEN (ELAPSED @ SPEED)"),
-        (36, "[download] WRITTEN (ELAPSED @ SPEED)"),
-        (35, "[download] WRITTEN (ELAPSED)"),
-        (28, "[download] WRITTEN (ELAPSED)"),
-        (27, "[download] WRITTEN"),
-        (1, "[download] WRITTEN"),
-    ], indirect=["term_width"])
+    @pytest.mark.parametrize(
+        ("term_width", "expected"),
+        [
+            (99, "[download] Written WRITTEN to PATH (ELAPSED @ SPEED)"),
+            (63, "[download] Written WRITTEN to PATH (ELAPSED @ SPEED)"),
+            (62, "[download] Written WRITTEN (ELAPSED @ SPEED)"),
+            (44, "[download] Written WRITTEN (ELAPSED @ SPEED)"),
+            (43, "[download] WRITTEN (ELAPSED @ SPEED)"),
+            (36, "[download] WRITTEN (ELAPSED @ SPEED)"),
+            (35, "[download] WRITTEN (ELAPSED)"),
+            (28, "[download] WRITTEN (ELAPSED)"),
+            (27, "[download] WRITTEN"),
+            (1, "[download] WRITTEN"),
+        ],
+        indirect=["term_width"],
+    )
     def test_format(self, params, term_width, expected):
         assert ProgressFormatter.format(ProgressFormatter.FORMATS, params) == expected
 
-    @pytest.mark.parametrize(("term_width", "expected"), [
-        (99, "[download] Written WRITTEN to PATH (ELAPSED)"),
-        (55, "[download] Written WRITTEN to PATH (ELAPSED)"),
-        (54, "[download] Written WRITTEN (ELAPSED)"),
-        (36, "[download] Written WRITTEN (ELAPSED)"),
-        (35, "[download] WRITTEN (ELAPSED)"),
-        (28, "[download] WRITTEN (ELAPSED)"),
-        (27, "[download] WRITTEN"),
-        (1, "[download] WRITTEN"),
-    ], indirect=["term_width"])
+    @pytest.mark.parametrize(
+        ("term_width", "expected"),
+        [
+            (99, "[download] Written WRITTEN to PATH (ELAPSED)"),
+            (55, "[download] Written WRITTEN to PATH (ELAPSED)"),
+            (54, "[download] Written WRITTEN (ELAPSED)"),
+            (36, "[download] Written WRITTEN (ELAPSED)"),
+            (35, "[download] WRITTEN (ELAPSED)"),
+            (28, "[download] WRITTEN (ELAPSED)"),
+            (27, "[download] WRITTEN"),
+            (1, "[download] WRITTEN"),
+        ],
+        indirect=["term_width"],
+    )
     def test_format_nospeed(self, params, term_width, expected):
         assert ProgressFormatter.format(ProgressFormatter.FORMATS_NOSPEED, params) == expected
 
@@ -62,44 +70,50 @@ class TestProgressFormatter:
         params["path"] = Mock(side_effect=ValueError("fail"))
         assert ProgressFormatter.format(ProgressFormatter.FORMATS, params) == "[download] Written WRITTEN (ELAPSED @ SPEED)"
 
-    @pytest.mark.parametrize(("size", "expected"), [
-        (0, "0 bytes"),
-        (2**10 - 1, "1023 bytes"),
-        (2**10, "1.00 KiB"),
-        (2**20 - 1, "1023.99 KiB"),
-        (2**20, "1.00 MiB"),
-        (2**30 - 1, "1023.99 MiB"),
-        (2**30, "1.00 GiB"),
-        (2**40 - 1, "1023.99 GiB"),
-        (2**40, "1.00 TiB"),
-        (2**50 - 1, "1023.99 TiB"),
-        (2**50, "1024.00 TiB"),
-    ])
+    @pytest.mark.parametrize(
+        ("size", "expected"),
+        [
+            (0, "0 bytes"),
+            (2**10 - 1, "1023 bytes"),
+            (2**10, "1.00 KiB"),
+            (2**20 - 1, "1023.99 KiB"),
+            (2**20, "1.00 MiB"),
+            (2**30 - 1, "1023.99 MiB"),
+            (2**30, "1.00 GiB"),
+            (2**40 - 1, "1023.99 GiB"),
+            (2**40, "1.00 TiB"),
+            (2**50 - 1, "1023.99 TiB"),
+            (2**50, "1024.00 TiB"),
+        ],
+    )
     def test_format_filesize(self, size, expected):
         assert ProgressFormatter.format_filesize(size) == expected
         assert ProgressFormatter.format_filesize(float(size)) == expected
         assert ProgressFormatter.format_filesize(size, "/s") == f"{expected}/s"
 
-    @pytest.mark.parametrize(("elapsed", "expected"), [
-        (-1, "0s"),
-        (0, "0s"),
-        (9, "9s"),
-        (10, "10s"),
-        (59, "59s"),
-        (60, "1m00s"),
-        (69, "1m09s"),
-        (70, "1m10s"),
-        (119, "1m59s"),
-        (120, "2m00s"),
-        (3599, "59m59s"),
-        (3600, "1h00m00s"),
-        (3659, "1h00m59s"),
-        (3660, "1h01m00s"),
-        (3661, "1h01m01s"),
-        (86399, "23h59m59s"),
-        (86400, "24h00m00s"),
-        (172800, "48h00m00s"),
-    ])
+    @pytest.mark.parametrize(
+        ("elapsed", "expected"),
+        [
+            (-1, "0s"),
+            (0, "0s"),
+            (9, "9s"),
+            (10, "10s"),
+            (59, "59s"),
+            (60, "1m00s"),
+            (69, "1m09s"),
+            (70, "1m10s"),
+            (119, "1m59s"),
+            (120, "2m00s"),
+            (3599, "59m59s"),
+            (3600, "1h00m00s"),
+            (3659, "1h00m59s"),
+            (3660, "1h01m00s"),
+            (3661, "1h01m01s"),
+            (86399, "23h59m59s"),
+            (86400, "24h00m00s"),
+            (172800, "48h00m00s"),
+        ],
+    )
     def test_format_time(self, elapsed, expected):
         assert ProgressFormatter.format_time(elapsed) == expected
 
@@ -117,89 +131,109 @@ class _TestFormatPath:
         assert ProgressFormatter.format_path(path, max_width) == expected
 
 
-@pytest.mark.parametrize(("path", "max_width", "expected"), [
-    pytest.param(_PATH_POSIX, 26, "/foobar/baz/some file name", id="full path"),
-    pytest.param(_PATH_POSIX, 25, "…oobar/baz/some file name", id="truncated by 1"),
-    pytest.param(_PATH_POSIX, 24, "…obar/baz/some file name", id="truncated by 2"),
-    pytest.param(_PATH_POSIX, 23, "…bar/baz/some file name", id="truncated by 3"),
-    pytest.param(_PATH_POSIX, 22, "…ar/baz/some file name", id="truncated by 4"),
-    pytest.param(_PATH_POSIX, 21, "…r/baz/some file name", id="truncated by 5"),
-    pytest.param(_PATH_POSIX, 20, "…/baz/some file name", id="truncated by 6"),
-    pytest.param(_PATH_POSIX, 19, "…baz/some file name", id="truncated by 7 (cuts off separator)"),
-    pytest.param(_PATH_POSIX, 16, "…/some file name", id="truncated (all parts except name)"),
-    pytest.param(_PATH_POSIX, 15, "…some file name", id="truncated (name without separator)"),
-    pytest.param(_PATH_POSIX, 14, "…ome file name", id="truncated name"),
-])
+@pytest.mark.parametrize(
+    ("path", "max_width", "expected"),
+    [
+        pytest.param(_PATH_POSIX, 26, "/foobar/baz/some file name", id="full path"),
+        pytest.param(_PATH_POSIX, 25, "…oobar/baz/some file name", id="truncated by 1"),
+        pytest.param(_PATH_POSIX, 24, "…obar/baz/some file name", id="truncated by 2"),
+        pytest.param(_PATH_POSIX, 23, "…bar/baz/some file name", id="truncated by 3"),
+        pytest.param(_PATH_POSIX, 22, "…ar/baz/some file name", id="truncated by 4"),
+        pytest.param(_PATH_POSIX, 21, "…r/baz/some file name", id="truncated by 5"),
+        pytest.param(_PATH_POSIX, 20, "…/baz/some file name", id="truncated by 6"),
+        pytest.param(_PATH_POSIX, 19, "…baz/some file name", id="truncated by 7 (cuts off separator)"),
+        pytest.param(_PATH_POSIX, 16, "…/some file name", id="truncated (all parts except name)"),
+        pytest.param(_PATH_POSIX, 15, "…some file name", id="truncated (name without separator)"),
+        pytest.param(_PATH_POSIX, 14, "…ome file name", id="truncated name"),
+    ],
+)
 class TestFormatPathPOSIX(_TestFormatPath):
     pass
 
 
-@pytest.mark.parametrize(("path", "max_width", "expected"), [
-    pytest.param(_PATH_WIN_ABS, 28, "C:\\foobar\\baz\\some file name", id="full path"),
-    pytest.param(_PATH_WIN_ABS, 27, "C:…oobar\\baz\\some file name", id="truncated by 1"),
-    pytest.param(_PATH_WIN_ABS, 26, "C:…obar\\baz\\some file name", id="truncated by 2"),
-    pytest.param(_PATH_WIN_ABS, 25, "C:…bar\\baz\\some file name", id="truncated by 3"),
-    pytest.param(_PATH_WIN_ABS, 24, "C:…ar\\baz\\some file name", id="truncated by 4"),
-    pytest.param(_PATH_WIN_ABS, 23, "C:…r\\baz\\some file name", id="truncated by 5"),
-    pytest.param(_PATH_WIN_ABS, 22, "C:…\\baz\\some file name", id="truncated by 6"),
-    pytest.param(_PATH_WIN_ABS, 21, "C:…baz\\some file name", id="truncated by 7 (cuts off separator)"),
-    pytest.param(_PATH_WIN_ABS, 18, "C:…\\some file name", id="truncated (all parts except name)"),
-    pytest.param(_PATH_WIN_ABS, 17, "C:…some file name", id="truncated (name without separator)"),
-    pytest.param(_PATH_WIN_ABS, 16, "C:…ome file name", id="truncated name"),
-])
+@pytest.mark.parametrize(
+    ("path", "max_width", "expected"),
+    [
+        pytest.param(_PATH_WIN_ABS, 28, "C:\\foobar\\baz\\some file name", id="full path"),
+        pytest.param(_PATH_WIN_ABS, 27, "C:…oobar\\baz\\some file name", id="truncated by 1"),
+        pytest.param(_PATH_WIN_ABS, 26, "C:…obar\\baz\\some file name", id="truncated by 2"),
+        pytest.param(_PATH_WIN_ABS, 25, "C:…bar\\baz\\some file name", id="truncated by 3"),
+        pytest.param(_PATH_WIN_ABS, 24, "C:…ar\\baz\\some file name", id="truncated by 4"),
+        pytest.param(_PATH_WIN_ABS, 23, "C:…r\\baz\\some file name", id="truncated by 5"),
+        pytest.param(_PATH_WIN_ABS, 22, "C:…\\baz\\some file name", id="truncated by 6"),
+        pytest.param(_PATH_WIN_ABS, 21, "C:…baz\\some file name", id="truncated by 7 (cuts off separator)"),
+        pytest.param(_PATH_WIN_ABS, 18, "C:…\\some file name", id="truncated (all parts except name)"),
+        pytest.param(_PATH_WIN_ABS, 17, "C:…some file name", id="truncated (name without separator)"),
+        pytest.param(_PATH_WIN_ABS, 16, "C:…ome file name", id="truncated name"),
+    ],
+)
 class TestFormatPathWindowsAbsolute(_TestFormatPath):
     pass
 
 
-@pytest.mark.parametrize(("path", "max_width", "expected"), [
-    pytest.param(_PATH_WIN_REL, 25, "foobar\\baz\\some file name", id="full path"),
-    pytest.param(_PATH_WIN_REL, 24, "…obar\\baz\\some file name", id="truncated by 1"),
-    pytest.param(_PATH_WIN_REL, 23, "…bar\\baz\\some file name", id="truncated by 2"),
-    pytest.param(_PATH_WIN_REL, 22, "…ar\\baz\\some file name", id="truncated by 3"),
-    pytest.param(_PATH_WIN_REL, 21, "…r\\baz\\some file name", id="truncated by 4"),
-    pytest.param(_PATH_WIN_REL, 20, "…\\baz\\some file name", id="truncated by 5"),
-    pytest.param(_PATH_WIN_REL, 19, "…baz\\some file name", id="truncated by 6 (cuts off separator)"),
-    pytest.param(_PATH_WIN_REL, 16, "…\\some file name", id="truncated (all parts except name)"),
-    pytest.param(_PATH_WIN_REL, 15, "…some file name", id="truncated (name without separator)"),
-    pytest.param(_PATH_WIN_REL, 14, "…ome file name", id="truncated name"),
-])
+@pytest.mark.parametrize(
+    ("path", "max_width", "expected"),
+    [
+        pytest.param(_PATH_WIN_REL, 25, "foobar\\baz\\some file name", id="full path"),
+        pytest.param(_PATH_WIN_REL, 24, "…obar\\baz\\some file name", id="truncated by 1"),
+        pytest.param(_PATH_WIN_REL, 23, "…bar\\baz\\some file name", id="truncated by 2"),
+        pytest.param(_PATH_WIN_REL, 22, "…ar\\baz\\some file name", id="truncated by 3"),
+        pytest.param(_PATH_WIN_REL, 21, "…r\\baz\\some file name", id="truncated by 4"),
+        pytest.param(_PATH_WIN_REL, 20, "…\\baz\\some file name", id="truncated by 5"),
+        pytest.param(_PATH_WIN_REL, 19, "…baz\\some file name", id="truncated by 6 (cuts off separator)"),
+        pytest.param(_PATH_WIN_REL, 16, "…\\some file name", id="truncated (all parts except name)"),
+        pytest.param(_PATH_WIN_REL, 15, "…some file name", id="truncated (name without separator)"),
+        pytest.param(_PATH_WIN_REL, 14, "…ome file name", id="truncated name"),
+    ],
+)
 class TestFormatPathWindowsRelative(_TestFormatPath):
     pass
 
 
-@pytest.mark.parametrize(("path", "max_width", "expected"), [
-    # <py312: server/host name is not part of the path's drive, so it'll get truncated
-    pytest.param(_PATH_WIN_UNC, 29, "\\\\?\\foobar\\baz\\some file name", id="full path"),
-    pytest.param(_PATH_WIN_UNC, 28, "\\\\?\\…obar\\baz\\some file name", id="truncated by 1"),
-    pytest.param(_PATH_WIN_UNC, 20, "\\\\?\\…\\some file name", id="truncated (all parts except name)"),
-    pytest.param(_PATH_WIN_UNC, 19, "\\\\?\\…some file name", id="truncated (name without separator)"),
-    pytest.param(_PATH_WIN_UNC, 18, "\\\\?\\…ome file name", id="truncated name"),
-] if sys.version_info < (3, 12) else [
-    # >=py312: server/host name is part of the path's drive, so it won't get truncated
-    pytest.param(_PATH_WIN_UNC, 29, "\\\\?\\foobar\\baz\\some file name", id="full path"),
-    pytest.param(_PATH_WIN_UNC, 28, "\\\\?\\foobar…az\\some file name", id="truncated by 1"),
-    pytest.param(_PATH_WIN_UNC, 26, "\\\\?\\foobar…\\some file name", id="truncated (all parts except name)"),
-    pytest.param(_PATH_WIN_UNC, 25, "\\\\?\\foobar…some file name", id="truncated (name without separator)"),
-    pytest.param(_PATH_WIN_UNC, 24, "\\\\?\\foobar…ome file name", id="truncated name"),
-])
+@pytest.mark.parametrize(
+    ("path", "max_width", "expected"),
+    [
+        # <py312: server/host name is not part of the path's drive, so it'll get truncated
+        pytest.param(_PATH_WIN_UNC, 29, "\\\\?\\foobar\\baz\\some file name", id="full path"),
+        pytest.param(_PATH_WIN_UNC, 28, "\\\\?\\…obar\\baz\\some file name", id="truncated by 1"),
+        pytest.param(_PATH_WIN_UNC, 20, "\\\\?\\…\\some file name", id="truncated (all parts except name)"),
+        pytest.param(_PATH_WIN_UNC, 19, "\\\\?\\…some file name", id="truncated (name without separator)"),
+        pytest.param(_PATH_WIN_UNC, 18, "\\\\?\\…ome file name", id="truncated name"),
+    ]
+    if sys.version_info < (3, 12)
+    else [
+        # >=py312: server/host name is part of the path's drive, so it won't get truncated
+        pytest.param(_PATH_WIN_UNC, 29, "\\\\?\\foobar\\baz\\some file name", id="full path"),
+        pytest.param(_PATH_WIN_UNC, 28, "\\\\?\\foobar…az\\some file name", id="truncated by 1"),
+        pytest.param(_PATH_WIN_UNC, 26, "\\\\?\\foobar…\\some file name", id="truncated (all parts except name)"),
+        pytest.param(_PATH_WIN_UNC, 25, "\\\\?\\foobar…some file name", id="truncated (name without separator)"),
+        pytest.param(_PATH_WIN_UNC, 24, "\\\\?\\foobar…ome file name", id="truncated name"),
+    ],
+)
 class TestFormatPathWindowsUniversalNamingConvention(_TestFormatPath):
     pass
 
 
 class TestWidth:
-    @pytest.mark.parametrize(("chars", "expected"), [
-        ("ABCDEFGHIJ", 10),
-        ("A你好世界こんにちは안녕하세요B", 30),
-        ("·「」『』【】-=！@#￥%……&×（）", 30),  # noqa: RUF001
-    ])
+    @pytest.mark.parametrize(
+        ("chars", "expected"),
+        [
+            ("ABCDEFGHIJ", 10),
+            ("A你好世界こんにちは안녕하세요B", 30),
+            ("·「」『』【】-=！@#￥%……&×（）", 30),  # noqa: RUF001
+        ],
+    )
     def test_width(self, chars, expected):
         assert ProgressFormatter.width(chars) == expected
 
-    @pytest.mark.parametrize(("prefix", "max_len", "expected"), [
-        ("你好世界こんにちは안녕하세요CD", 10, "녕하세요CD"),
-        ("你好世界こんにちは안녕하세요CD", 9, "하세요CD"),
-        ("你好世界こんにちは안녕하세요CD", 23, "こんにちは안녕하세요CD"),
-    ])
+    @pytest.mark.parametrize(
+        ("prefix", "max_len", "expected"),
+        [
+            ("你好世界こんにちは안녕하세요CD", 10, "녕하세요CD"),
+            ("你好世界こんにちは안녕하세요CD", 9, "하세요CD"),
+            ("你好世界こんにちは안녕하세요CD", 23, "こんにちは안녕하세요CD"),
+        ],
+    )
     def test_cut(self, prefix, max_len, expected):
         assert ProgressFormatter.cut(prefix, max_len) == expected
 
