@@ -6,10 +6,10 @@ class TestPluginCanHandleUrlARDLive(PluginCanHandleUrl):
     __plugin__ = ARDLive
 
     should_match = [
-        'https://daserste.de/live/index.html',
-        'https://www.daserste.de/live/index.html',
+        "https://daserste.de/live/index.html",
+        "https://www.daserste.de/live/index.html",
     ]
 
     should_not_match = [
-        'http://mediathek.daserste.de/live',
+        "http://mediathek.daserste.de/live",
     ]
