@@ -5,9 +5,15 @@ from tests.plugins import PluginCanHandleUrl
 class TestPluginCanHandleUrlBBCiPlayer(PluginCanHandleUrl):
     __plugin__ = BBCiPlayer
 
-    should_match = [
-        "http://www.bbc.co.uk/iplayer/episode/b00ymh67/madagascar-1-island-of-marvels",
-        "http://www.bbc.co.uk/iplayer/live/bbcone",
+    should_match_groups = [
+        (
+            ("live", "http://www.bbc.co.uk/iplayer/live/bbcone"),
+            {"channel_name": "bbcone"},
+        ),
+        (
+            ("episode", "http://www.bbc.co.uk/iplayer/episode/b00ymh67/madagascar-1-island-of-marvels"),
+            {"episode_id": "b00ymh67"},
+        ),
     ]
 
     should_not_match = [
