@@ -5,7 +5,7 @@ from tests.plugins import PluginCanHandleUrl
 class TestPluginCanHandleUrlPandalive(PluginCanHandleUrl):
     __plugin__ = Pandalive
 
-    should_match = [
-        "https://www.pandalive.co.kr/live/play/pocet00",
-        "https://www.pandalive.co.kr/live/play/rladbfl1208",
+    should_match_groups = [
+        ("https://www.pandalive.co.kr/live/play/CHANNEL", {"channel": "CHANNEL"}),
+        ("https://w2.pandalive.co.kr/en/play/CHANNEL", {"channel": "CHANNEL"}),
     ]
