@@ -1,13 +1,15 @@
+from __future__ import annotations
+
 import logging
 import os
 import sys
 import warnings
+from collections.abc import Iterable
 from datetime import timezone
 from errno import EINVAL, EPIPE
 from inspect import currentframe, getframeinfo
 from io import BytesIO, TextIOWrapper
 from pathlib import Path
-from typing import Iterable, Optional, Tuple, Type
 
 import freezegun
 import pytest
@@ -45,7 +47,7 @@ def log(request: pytest.FixtureRequest, monkeypatch: pytest.MonkeyPatch, output:
     if "logfile" in request.fixturenames:
         params["filename"] = request.getfixturevalue("logfile")
 
-    stream: Optional[TextIOWrapper] = output
+    stream: TextIOWrapper | None = output
     if not params.pop("stdout", True):
         stream = None
     if not params.pop("stderr", True):
@@ -87,16 +89,19 @@ class TestLogging:
 
         return cm.value
 
-    @pytest.mark.parametrize(("name", "level"), [
-        ("none", logger.NONE),
-        ("critical", logger.CRITICAL),
-        ("error", logger.ERROR),
-        ("warning", logger.WARNING),
-        ("info", logger.INFO),
-        ("debug", logger.DEBUG),
-        ("trace", logger.TRACE),
-        ("all", logger.ALL),
-    ])
+    @pytest.mark.parametrize(
+        ("name", "level"),
+        [
+            ("none", logger.NONE),
+            ("critical", logger.CRITICAL),
+            ("error", logger.ERROR),
+            ("warning", logger.WARNING),
+            ("info", logger.INFO),
+            ("debug", logger.DEBUG),
+            ("trace", logger.TRACE),
+            ("all", logger.ALL),
+        ],
+    )
     def test_level_names(self, name: str, level: int):
         assert logging.getLevelName(level) == name
         assert logging.getLevelName(name) == level
@@ -134,24 +139,30 @@ class TestLogging:
         log.debug("test")
         assert getvalue(output) == "[test][debug] test\n"
 
-    @pytest.mark.parametrize(("loglevel", "calllevel", "expected"), [
-        (logger.DEBUG, logger.TRACE, ""),
-        (logger.TRACE, logger.TRACE, "[test][trace] test\n"),
-        (logger.TRACE, logger.DEBUG, "[test][debug] test\n"),
-        (logger.TRACE, logger.ALL, ""),
-        (logger.ALL, logger.ALL, "[test][all] test\n"),
-        (logger.ALL, logger.TRACE, "[test][trace] test\n"),
-    ])
+    @pytest.mark.parametrize(
+        ("loglevel", "calllevel", "expected"),
+        [
+            (logger.DEBUG, logger.TRACE, ""),
+            (logger.TRACE, logger.TRACE, "[test][trace] test\n"),
+            (logger.TRACE, logger.DEBUG, "[test][debug] test\n"),
+            (logger.TRACE, logger.ALL, ""),
+            (logger.ALL, logger.ALL, "[test][all] test\n"),
+            (logger.ALL, logger.TRACE, "[test][trace] test\n"),
+        ],
+    )
     def test_custom_output(self, log: logging.Logger, output: TextIOWrapper, loglevel: int, calllevel: int, expected: str):
         log.setLevel(loglevel)
         log.log(calllevel, "test")
         assert getvalue(output) == expected
 
     # https://github.com/streamlink/streamlink/issues/4862
-    @pytest.mark.parametrize(("level", "levelname"), [
-        (logger.TRACE, "trace"),
-        (logger.ALL, "all"),
-    ])
+    @pytest.mark.parametrize(
+        ("level", "levelname"),
+        [
+            (logger.TRACE, "trace"),
+            (logger.ALL, "all"),
+        ],
+    )
     def test_custom_module_name(self, caplog: pytest.LogCaptureFixture, log: logging.Logger, level: int, levelname: str):
         caplog.set_level(1)
         log = logging.getLogger(self.__class__.__module__)
@@ -162,10 +173,13 @@ class TestLogging:
             ("test_logger", levelname, "bar"),
         ]
 
-    @pytest.mark.parametrize(("level", "expected"), [
-        (logger.DEBUG, ""),
-        (logger.INFO, "[test][info] foo\n[test][info] bar\n"),
-    ])
+    @pytest.mark.parametrize(
+        ("level", "expected"),
+        [
+            (logger.DEBUG, ""),
+            (logger.INFO, "[test][info] foo\n[test][info] bar\n"),
+        ],
+    )
     def test_iter(self, log: logger.StreamlinkLogger, output: TextIOWrapper, level: int, expected: str):
         def iterator():
             yield "foo"
@@ -175,9 +189,13 @@ class TestLogging:
         assert list(log.iter(level, iterator())) == ["foo", "bar"]
         assert getvalue(output) == expected
 
-    @pytest.mark.parametrize("log", [
-        {"style": "%", "format": "[%(name)s][%(levelname)s] %(message)s"},
-    ], indirect=True)
+    @pytest.mark.parametrize(
+        "log",
+        [
+            {"style": "%", "format": "[%(name)s][%(levelname)s] %(message)s"},
+        ],
+        indirect=True,
+    )
     def test_style_percent(self, log: logging.Logger, output: TextIOWrapper):
         log.setLevel("info")
         log.info("test")
@@ -189,45 +207,57 @@ class TestLogging:
         assert str(log_failure) == "Style must be one of: %,{,$"
 
     @freezegun.freeze_time("2000-01-02T03:04:05.123456Z")
-    @pytest.mark.parametrize("log", [
-        {"format": "[{asctime}][{name}][{levelname}] {message}"},
-    ], indirect=True)
+    @pytest.mark.parametrize(
+        "log",
+        [
+            {"format": "[{asctime}][{name}][{levelname}] {message}"},
+        ],
+        indirect=True,
+    )
     def test_datefmt_default(self, log: logging.Logger, output: TextIOWrapper):
         log.setLevel("info")
         log.info("test")
         assert getvalue(output) == "[03:04:05][test][info] test\n"
 
     @freezegun.freeze_time("2000-01-02T03:04:05.123456Z")
-    @pytest.mark.parametrize("log", [
-        {"format": "[{asctime}][{name}][{levelname}] {message}", "datefmt": "%H:%M:%S.%f%z"},
-    ], indirect=True)
+    @pytest.mark.parametrize(
+        "log",
+        [
+            {"format": "[{asctime}][{name}][{levelname}] {message}", "datefmt": "%H:%M:%S.%f%z"},
+        ],
+        indirect=True,
+    )
     def test_datefmt_custom(self, log: logging.Logger, output: TextIOWrapper):
         log.setLevel("info")
         log.info("test")
         assert getvalue(output) == "[03:04:05.123456+0000][test][info] test\n"
 
-    @pytest.mark.parametrize(("output", "expected"), [
-        pytest.param(
-            {"encoding": "utf-8"},
-            "Bär: 🐻",
-            id="utf-8",
-        ),
-        pytest.param(
-            {"encoding": "ascii"},
-            "B\\xe4r: \\U0001f43b",
-            id="ascii",
-        ),
-        pytest.param(
-            {"encoding": "iso-8859-1"},
-            "Bär: \\U0001f43b",
-            id="iso-8859-1",
-        ),
-        pytest.param(
-            {"encoding": "shift_jis"},
-            "B\\xe4r: \\U0001f43b",
-            id="shift_jis",
-        ),
-    ], indirect=["output"])
+    @pytest.mark.parametrize(
+        ("output", "expected"),
+        [
+            pytest.param(
+                {"encoding": "utf-8"},
+                "Bär: 🐻",
+                id="utf-8",
+            ),
+            pytest.param(
+                {"encoding": "ascii"},
+                "B\\xe4r: \\U0001f43b",
+                id="ascii",
+            ),
+            pytest.param(
+                {"encoding": "iso-8859-1"},
+                "Bär: \\U0001f43b",
+                id="iso-8859-1",
+            ),
+            pytest.param(
+                {"encoding": "shift_jis"},
+                "B\\xe4r: \\U0001f43b",
+                id="shift_jis",
+            ),
+        ],
+        indirect=["output"],
+    )
     def test_logstream_encoding(self, log: logging.Logger, output: TextIOWrapper, expected: str):
         log.setLevel("info")
         log.info("Bär: 🐻")
@@ -312,7 +342,7 @@ class TestLogging:
 
 class TestCaptureWarnings:
     @staticmethod
-    def _warn(messages: Iterable[Tuple[str, Type[Warning]]], filterwarnings=None):
+    def _warn(messages: Iterable[tuple[str, type[Warning]]], filterwarnings=None):
         frame = currentframe()
         assert frame
         assert frame.f_back
@@ -331,19 +361,22 @@ class TestCaptureWarnings:
         assert getvalue(output) == ""
 
     @pytest.mark.parametrize("log", [{"capture_warnings": True}], indirect=["log"])
-    @pytest.mark.parametrize(("warning", "expected", "origin"), [
-        (("Test warning", UserWarning), "[warnings][userwarning] Test warning\n", True),
-        (("Test warning", DeprecationWarning), "[warnings][deprecationwarning] Test warning\n", True),
-        (("Test warning", FutureWarning), "[warnings][futurewarning] Test warning\n", True),
-        (("Test warning", StreamlinkWarning), "[warnings][streamlinkwarning] Test warning\n", False),
-        (("Test warning", StreamlinkDeprecationWarning), "[warnings][streamlinkdeprecation] Test warning\n", False),
-    ])
+    @pytest.mark.parametrize(
+        ("warning", "expected", "origin"),
+        [
+            (("Test warning", UserWarning), "[warnings][userwarning] Test warning\n", True),
+            (("Test warning", DeprecationWarning), "[warnings][deprecationwarning] Test warning\n", True),
+            (("Test warning", FutureWarning), "[warnings][futurewarning] Test warning\n", True),
+            (("Test warning", StreamlinkWarning), "[warnings][streamlinkwarning] Test warning\n", False),
+            (("Test warning", StreamlinkDeprecationWarning), "[warnings][streamlinkdeprecation] Test warning\n", False),
+        ],
+    )
     def test_capture(
         self,
         recwarn: pytest.WarningsRecorder,
         log: logging.Logger,
         output: TextIOWrapper,
-        warning: Tuple[str, Type[Warning]],
+        warning: tuple[str, type[Warning]],
         expected: str,
         origin: bool,
     ):
@@ -392,17 +425,20 @@ class TestCaptureWarnings:
         assert getvalue(output) == f"[warnings][userwarning] foo\n  {__file__}:{lineno}\n"
 
     @pytest.mark.parametrize("log", [{"capture_warnings": True}], indirect=["log"])
-    @pytest.mark.parametrize("warning", [
-        ("Test warning", UserWarning),
-        ("Test warning", DeprecationWarning),
-        ("Test warning", FutureWarning),
-    ])
+    @pytest.mark.parametrize(
+        "warning",
+        [
+            ("Test warning", UserWarning),
+            ("Test warning", DeprecationWarning),
+            ("Test warning", FutureWarning),
+        ],
+    )
     def test_ignored(
         self,
         recwarn: pytest.WarningsRecorder,
         log: logging.Logger,
         output: TextIOWrapper,
-        warning: Tuple[str, Type[Warning]],
+        warning: tuple[str, type[Warning]],
     ):
         self._warn([warning], filterwarnings="ignore")
         assert recwarn.list == []
